package com.level3.mediaportal.api.exampleCode;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

public class APISampleCodeJava {
	
	public static void main(String[] args) {
		String keyId = null; //API Key Id goes here.
		String keySecret = null; //API Key Secret goes here.
		APICommunicatorJava comm = new APICommunicatorJava(keyId, keySecret); 

		//testAPICallGet(comm);		
		//testAPICallPost(comm); //Be sure to update URI before running
	}	
	
	/**
	 * Fetch the current GMT time in a format supported by 
	 * the Media Portal API.
	 * 
	 * @return The current date/time formatted as "Mon, 01 Jan 2018 00:00:00 GMT"
	 * */
	public static String getCurrentTime() {
		final Date currentTime = new Date();

		final SimpleDateFormat formatter =
		        new SimpleDateFormat("EEE, dd MMM yyyy HH:mm:ss z");

		formatter.setTimeZone(TimeZone.getTimeZone("GMT"));
		return formatter.format(currentTime);
	}
	
	/**
	 * A Test GET call to the Media Portal API. Some fields 
	 * have been pre-filled out, as appropriate. An example 
	 * API call is included below.
	 * */
	public static void testAPICallGet(APICommunicatorJava comm) {
		System.out.println("****************GET CALL TEST****************");
		
		String accept = "application/json";
		String dateStr = getCurrentTime(); 
		
		String url = "https://ws.level3.com/key/v1.0";
		
		String response = comm.sendTestAPICallGET(accept, dateStr, url);
		System.out.println("*****Response*****");
		System.out.println(response);
		System.out.println("******************");

		System.out.println("*********************************************\n\n");
	}

	/**
	 * A Test POST call to the Media Portal API. Some fields 
	 * have been pre-filled out, as appropriate. An example 
	 * API call is included with areas marked for you to input 
	 * your own data.
	 * */
	public static void testAPICallPost(APICommunicatorJava comm) {
		System.out.println("****************GET CALL TEST****************");
		
		String accept = "application/json";
		String contentType = "application/json";
		String dateStr = getCurrentTime();
		String postBody = "{\"paths\":[\"/fake/path/for/testing/nonexistantFile.jpg\"]}";

		//Example URL, with info filled out:
		//   https://ws.level3.com/invalidations/v1.0/0000/BB000/apiCall.property.test.net?force=false&ignoreCase=false&notification=test@email.com
		//   ("?" and parameters are optional) 
		String url = "https://ws.level3.com/invalidations/v1.0/{agid}[/{scid}][/{property}]?[force=true|false][&ignoreCase=true|false][&notification={email}]";
		
		String response = comm.sendTestAPICallPOST(accept, contentType, dateStr, postBody, url);
		
		System.out.println("*****Response*****");
		System.out.println(response);
		System.out.println("******************");
		
		System.out.println("*********************************************\n\n");
	}

}
